import{v as n,Q as l,aa as c,c as u,K as a,y as h,E as f,l as w,L as b}from"./index-2ed92f93.js";import{_ as d}from"./ItemsListing.vue_vue_type_style_index_0_lang-d2bd3bdf.js";import"./ListviewItem-ccf2487f.js";import"./VBadge-37788c48.js";import"./Container-49aaa795.js";import"./forwardRefs-b2545869.js";import"./VMenu-16697a26.js";/* empty css              */import"./VCheckboxBtn-f2c5d38b.js";import"./VSlideGroup-dd4dc020.js";import"./VCard-c4a81832.js";import"./VCardText-2fda0657.js";import"./VTooltip-11295f6e.js";import"./PanelviewItem.vue_vue_type_style_index_0_lang-12716644.js";import"./contextmenu-66a55ea8.js";import"./Alert-d5f867ed.js";import"./VAlert-85a681b8.js";import"./VToolbar-25636a36.js";import"./VTextField-e0cdad59.js";import"./VVirtualScroll-63a0b7fb.js";const A=n({__name:"BrowseView",props:{path:{}},setup(s){const t=s,{t:o}=l();c();const p=u(()=>!t.path||t.path=="root"?o("browse"):a("bp6")?o("browse")+" | "+t.path:a("bp3")?t.path:o("browse")),i=async function(e){const r=[];return await b.browse(t.path,m=>{r.push(...m)}),r};return(e,r)=>(h(),f("section",null,[w(d,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-items":i,"sort-keys":["original","name","name_desc"],title:p.value,path:e.path,"allow-key-hooks":!0},null,8,["title","path"])]))}});export{A as default};
