import{c as a,y as n,z as l,Z as p,G as c,A as _,$ as i,n as m}from"./index-2ed92f93.js";import{a as u}from"./Container-49aaa795.js";import{V as f}from"./VAlert-85a681b8.js";const d={setup(r,t){const e=a(()=>({}));return{alertProps:a(()=>({...e.value,...t.attrs}))}}};function $(r,t,e,s,y,A){return n(),l(f,m(s.alertProps,{class:"alert",color:"primary",density:"compact",prominent:""}),p({_:2},[c(r.$slots,(v,o)=>({name:o,fn:_(()=>[i(r.$slots,o)])}))]),1040)}const h=u(d,[["render",$]]);export{h as A};
